@@ -40,25 +40,15 @@ enum {
 static constexpr const auto SQUARE_MAX_ASPECT = 1.25f;
 static constexpr const auto PDF417_MIN_ASPECT = 1.5f;
 static constexpr const auto PDF417_MAX_ASPECT = 6.0f;
-static constexpr const auto ANY1D_MIN_ASPECT = 6.0f;
+static constexpr const auto ANY1D_MIN_ASPECT = 4.0f;
+static constexpr const auto ANY1D_MAX_ASPECT = 8.0f;
 
 BarcodeDecoder::BarcodeDecoder() = default;
 BarcodeDecoder::~BarcodeDecoder() = default;
 
-bool BarcodeDecoder::isBarcode(const QImage &img, BarcodeDecoder::BarcodeTypes hint) const
-{
-    if (!maybeBarcode(img.width(), img.height(), hint)) {
-        return false;
-    }
-
-    auto &result = m_cache[img.cacheKey()];
-    decodeIfNeeded(img, hint, result);
-    return hint & result.positive;
-}
-
 QByteArray BarcodeDecoder::decodeBinary(const QImage &img, BarcodeDecoder::BarcodeTypes hint) const
 {
-    if (!maybeBarcode(img.width(), img.height(), hint)) {
+    if (hint == None || img.isNull()) {
         return {};
     }
 
@@ -73,7 +63,7 @@ QByteArray BarcodeDecoder::decodeBinary(const QImage &img, BarcodeDecoder::Barco
 
 QString BarcodeDecoder::decodeString(const QImage &img, BarcodeDecoder::BarcodeTypes hint) const
 {
-    if (!maybeBarcode(img.width(), img.height(), hint)) {
+    if (hint == None || img.isNull()) {
         return {};
     }
 
@@ -91,21 +81,24 @@ void BarcodeDecoder::clearCache()
     m_cache.clear();
 }
 
-bool BarcodeDecoder::isPlausibleSize(int width, int height, BarcodeDecoder::BarcodeTypes hint)
+BarcodeDecoder::BarcodeTypes BarcodeDecoder::isPlausibleSize(int width, int height, BarcodeDecoder::BarcodeTypes hint)
 {
     // normalize to landscape
     if (height > width) {
         std::swap(width, height);
     }
 
-    return width > MinSourceImageWidth && height > MinSourceImageHeight
-        && ((width < MaxSourceImageWidth && height < MaxSourceImageHeight) || (hint & IgnoreAspectRatio));
+    if (width > MinSourceImageWidth && height > MinSourceImageHeight
+        && ((width < MaxSourceImageWidth && height < MaxSourceImageHeight) || (hint & IgnoreAspectRatio))) {
+        return hint;
+    }
+    return None;
 }
 
-bool BarcodeDecoder::isPlausibleAspectRatio(int width, int height, BarcodeDecoder::BarcodeTypes hint)
+BarcodeDecoder::BarcodeTypes BarcodeDecoder::isPlausibleAspectRatio(int width, int height, BarcodeDecoder::BarcodeTypes hint)
 {
     if (hint & IgnoreAspectRatio) {
-        return true;
+        return hint;
     }
 
     // normalize to landscape
@@ -116,26 +109,26 @@ bool BarcodeDecoder::isPlausibleAspectRatio(int width, int height, BarcodeDecode
     const auto aspectRatio = (float)width / (float)height;
 
     // almost square, assume Aztec or QR
-    if (aspectRatio < SQUARE_MAX_ASPECT && (hint & AnySquare)) {
-        return true;
+    if (aspectRatio > SQUARE_MAX_ASPECT) {
+        hint &= ~AnySquare;
     }
 
     // rectangular with medium aspect ratio, such as PDF 417
-    if (aspectRatio > PDF417_MIN_ASPECT && aspectRatio < PDF417_MAX_ASPECT && (hint & PDF417)) {
-        return true;
+    if (aspectRatio < PDF417_MIN_ASPECT || aspectRatio > PDF417_MAX_ASPECT) {
+        hint &= ~PDF417;
     }
 
     // 1D
-    if (aspectRatio > ANY1D_MIN_ASPECT && (hint & Any1D)) {
-        return true;
+    if (aspectRatio < ANY1D_MIN_ASPECT || aspectRatio > ANY1D_MAX_ASPECT) {
+        hint &= ~Any1D;
     }
 
-    return false;
+    return hint;
 }
 
-bool BarcodeDecoder::maybeBarcode(int width, int height, BarcodeDecoder::BarcodeTypes hint)
+BarcodeDecoder::BarcodeTypes BarcodeDecoder::maybeBarcode(int width, int height, BarcodeDecoder::BarcodeTypes hint)
 {
-    return isPlausibleSize(width, height, hint) && isPlausibleAspectRatio(width, height, hint);
+    return isPlausibleSize(width, height, hint) & isPlausibleAspectRatio(width, height, hint);
 }
 
 #if HAVE_ZXING
@@ -303,42 +296,5 @@ void BarcodeDecoder::decodeIfNeeded(const QImage &img, BarcodeDecoder::BarcodeTy
         return;
     }
 
-    if (hint & IgnoreAspectRatio) {
-        decodeZxing(img, hint, result);
-        return;
-    }
-
-    const auto aspectRatio = img.width() < img.height() ?
-        (float)img.height() / (float)img.width() :
-        (float)img.width() / (float)img.height();
-
-    if (aspectRatio < SQUARE_MAX_ASPECT && (hint & AnySquare) && (result.negative & hint & AnySquare) != (hint & AnySquare)) {
-        decodeZxing(img, hint & AnySquare, result);
-    }
-
-    if (aspectRatio > PDF417_MIN_ASPECT && aspectRatio < PDF417_MAX_ASPECT && (hint  & PDF417) && (result.negative & hint & PDF417) != (hint & PDF417)) {
-        auto normalizedImg = img;
-        // newer ZXing versions handle rotated/flipped codes themselves correctly
-#if !ZXING_USE_READBARCODE
-        if (normalizedImg.width() < normalizedImg.height()) {
-            QTransform tf;
-            tf.rotate(-90);
-            normalizedImg = normalizedImg.transformed(tf);
-        }
-#endif
-
-        decodeZxing(normalizedImg, PDF417, result);
-#if !ZXING_USE_READBARCODE
-        if (result.positive & PDF417) {
-            return;
-        }
-        // try flipped around the x axis, zxing doesn't detect that, but it's e.g. encountered in SAS passes
-        result.negative &= ~PDF417;
-        decodeZxing(normalizedImg.transformed(QTransform{1, 0, 0, -1, 0, 0}), PDF417, result);
-#endif
-    }
-
-    if (aspectRatio > ANY1D_MIN_ASPECT && (hint & Any1D) && (result.negative & hint & Any1D) != (hint & Any1D)) {
-        decodeZxing(img, hint & Any1D, result);
-    }
+    decodeZxing(img, hint, result);
 }
