@@ -48,6 +48,7 @@ public:
     BarcodeDecoder m_barcodeDecoder;
     QString m_usedExtractor;
     ExtractorScriptEngine m_scriptEngine;
+    ExtractorEngine::Hints m_hints = ExtractorEngine::NoHint;
 };
 
 }
@@ -137,6 +138,16 @@ void ExtractorEngine::setContextDate(const QDateTime &dt)
     d->m_contextNode.setContextDateTime(dt);
 }
 
+ExtractorEngine::Hints ExtractorEngine::hints() const
+{
+    return d->m_hints;
+}
+
+void ExtractorEngine::setHints(ExtractorEngine::Hints hints)
+{
+    d->m_hints = hints;
+}
+
 QJsonArray ExtractorEngine::extract()
 {
     d->m_rootNode.setParent(d->m_contextNode);
