@@ -5,15 +5,19 @@
 */
 
 #include "pdfextractoroutputdevice_p.h"
+#include "pdfbarcodeutil_p.h"
 #include "pdfimage.h"
 #include "pdfimage_p.h"
 #include "popplerutils_p.h"
 
+#include <Annot.h>
+#include <Link.h>
+#include <Page.h>
+
 #include <QDebug>
 
 using namespace KItinerary;
 
-#ifdef HAVE_POPPLER
 PdfExtractorOutputDevice::PdfExtractorOutputDevice()
     : TextOutputDev(nullptr, false, 0, false, false)
 {
@@ -54,7 +58,7 @@ void PdfExtractorOutputDevice::drawImage(GfxState* state, Object* ref, Stream* s
     pdfImg.d->m_height = height;
     // deal with aspect-ratio changing scaling
     const auto sourceAspectRatio = (double)width / (double)height;
-    const auto targetAspectRatio = state->getCTM()[0] / -state->getCTM()[3];
+    const auto targetAspectRatio = std::abs(state->getCTM()[0] / -state->getCTM()[3]);
     if (!qFuzzyCompare(sourceAspectRatio, targetAspectRatio) && qFuzzyIsNull(state->getCTM()[1]) && qFuzzyIsNull(state->getCTM()[2])) {
         if (targetAspectRatio > sourceAspectRatio) {
             pdfImg.d->m_width = width * targetAspectRatio / sourceAspectRatio;
@@ -220,7 +224,7 @@ void PdfExtractorOutputDevice::finalize()
 
 void PdfExtractorOutputDevice::addVectorImage(const PdfVectorPicture &pic)
 {
-    if (pic.pathElementsCount() < 400) { // not complex enough for a barcode
+    if (PdfBarcodeUtil::isPlausiblePath(pic.pathElementsCount(), BarcodeDecoder::Any) == BarcodeDecoder::None) {
         return;
     }
 
@@ -234,4 +238,20 @@ void PdfExtractorOutputDevice::addVectorImage(const PdfVectorPicture &pic)
     m_images.push_back(img);
 }
 
-#endif
+void PdfExtractorOutputDevice::processLink(AnnotLink *link)
+{
+    TextOutputDev::processLink(link);
+    if (!link->isOk() || link->getAction()->getKind() != actionURI) {
+        return;
+    }
+
+    const auto uriLink = static_cast<LinkURI*>(link->getAction());
+    double xd1, yd1, xd2, yd2;
+    link->getRect(&xd1, &yd1, &xd2, &yd2);
+
+    double xu1, yu1, xu2, yu2;
+    cvtDevToUser(xd1, yd1, &xu1, &yu1);
+    cvtDevToUser(xd2, yd2, &xu2, &yu2);
+    PdfLink l(QString::fromStdString(uriLink->getURI()), QRectF(QPointF(std::min(xu1, xu2), std::min(yu1, yu2)), QPointF(std::max(xu1, xu2), std::max(yu1, yu2))));
+    m_links.push_back(std::move(l));
+}
