@@ -5,6 +5,7 @@
 */
 
 #include "pdfdocumentprocessor.h"
+#include "barcodedocumentprocessorhelper.h"
 #include "pdf/pdfbarcodeutil_p.h"
 
 #include <KItinerary/BarcodeDecoder>
@@ -95,7 +96,8 @@ void PdfDocumentProcessor::expandNode(ExtractorDocumentNode &node, const Extract
                 continue;
             }
 
-            if (!PdfBarcodeUtil::maybeBarcode(img)) {
+            const auto barcodeHints = PdfBarcodeUtil::maybeBarcode(img, BarcodeDecoder::Any2D | BarcodeDecoder::Any1D);
+            if (barcodeHints == BarcodeDecoder::None) {
                 continue;
             }
 
@@ -110,6 +112,10 @@ void PdfDocumentProcessor::expandNode(ExtractorDocumentNode &node, const Extract
             if (img.hasObjectId()) {
                 m_imageIds.insert(img.objectId());
             }
+
+            // technically not our job to do this here rather than letting the image node processor handle this
+            // but we have the output aspect ratio of the barcode only here, which gives better decoding hints
+            BarcodeDocumentProcessorHelper::expandNode(imgData, barcodeHints, childNode, engine);
         }
 
         // handle full page raster images
